## Progress Ledger

### Progress Questions

To make progress on answering the question, please answer the following questions, including necessary reasoning:

1. Are we able to answer the original question?
    - Is our original question fully answered? Consider the initial question, along with the facts we have gathered.
    - If we have an answer to the original question, but all that remains is to consolidate our findings, then we should consider our work complete. This work will be done after the plan is completed, you don't need to worry about it.

Consider the active test we're working on:

2. Have we completed work on the current test? 
    - Has the test goal been achieved?
    - We might not have completed all of the planned actions in the test, but if we have achieved the goal of the test, then we can consider it complete.

3. Do our test results indicate that we need to adjust our test plan? 
    - Don't consider errors or issues here - we will address those later. If we're still trying to obtain test results, then we should not adjust our test plan yet.
    - Did we learn something new that requires modifying the next steps in our test plan?
    - Did we learn something new that requires adjusting or creating a new hypothesis?
    

4. Do we have additional evidence to add to the test results? Consider the following things if they are relvant to our current test or our hypothesis:
    - Facts we have discovered
    - Useful references we may have found

The following questions are meant to determine if we're stuck and need to re-evaluate our current plan:

5. Are we in a loop where we keep repeating the same request without making progress?
    - If we have issued the same command multiple times without making progress, then we are in a loop.

6. Are we making forward progress? 
    - This means our most recent actions are leading us to new evidence or a new hypothesis.

7. Are we encountering issues that are preventing us from making progress? If so, please describe them. Consider:
    - Is one of our team members getting repeatedly stuck, or encountering the same issues?
    - Is our team composition not adequate for the current test?
    - Are we missing any resources that are preventing us from making progress?

8. If we're not done the question and we're not requesting a replan, then what are our next instructions, and who should we assign them to?
    - Consider the next steps we should take to make progress on the test.
    - Remember we only have access to the team members we have explicitly mentioned. There are no others!
    - If we're requesting a replan, or our work is fully complete, skip providing this please.




